#ifndef WINDND_H
#define WINDND_H

#include <gtk/gtk.h>
#include "win.h"


extern void WinAnimIconDataReceivedCB(
        GtkWidget *widget, GdkDragContext *dc,
        gint x, gint y,
        GtkSelectionData *selection_data, guint info, guint t,
        gpointer data
);

extern void WinListDNDSetIcon(
	GtkCList *clist, gint row, gint column
); 
extern void WinListDragDataGetCB(
	GtkWidget *widget, GdkDragContext *dc,
	GtkSelectionData *selection_data, guint info, guint t,
	gpointer data
);
extern void WinListDragDataReceivedCB(
	GtkWidget *widget, GdkDragContext *dc,
	gint x, gint y,
	GtkSelectionData *selection_data, guint info, guint t,
	gpointer data
);
extern void WinListDragDataDeleteCB(
	GtkWidget *widget, GdkDragContext *dc, gpointer data
);

extern void WinEntryDragDataReceivedCB(
        GtkWidget *widget, GdkDragContext *dc,   
        gint x, gint y,
        GtkSelectionData *selection_data, guint info, guint t,
        gpointer data
);


#endif	/* WINDND_H */
